#
# spec file for package moreutils
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           moreutils
Version:        0.70
Release:        1.2
Summary:        Additional Unix Utilities
# sponge — GPL2
# isutf8 — BSD-2-Clause
# mispipe — GPL2+ or MIT
# lckdo — Public domain
# everything else — GPL2+
License:        GPL-2.0-only AND GPL-2.0-or-later AND (GPL-2.0-or-later OR MIT) AND BSD-2-Clause AND SUSE-Public-Domain
Group:          Productivity/File utilities
URL:            https://joeyh.name/code/moreutils/
Source0:         https://git.joeyh.name/index.cgi/moreutils.git/snapshot/%{name}-%{version}.tar.gz
Patch0:         makefile.patch
BuildRequires:  docbook-xsl-stylesheets

%description
This is a growing collection of the Unix tools that nobody thought to write long ago, when Unix was young.

So far, it includes the following utilities:

  - chronic: runs a command quietly unless it fails
  - combine: combine the lines in two files using boolean operations
  - errno: look up errno names and descriptions
  - ifdata: get network interface info without parsing ifconfig output
  - ifne: run a program if the standard input is not empty
  - isutf8: check if a file or standard input is utf-8
  - lckdo: execute a program with a lock held
  - mispipe: pipe two commands, returning the exit status of the first
  - parallel: run multiple jobs at once
  - pee: tee standard input to pipes
  - sponge: soak up standard input and write to a file
  - ts: timestamp standard input
  - vidir: edit a directory in your text editor
  - vipe: insert a text editor into a pipe
  - zrun: automatically uncompress arguments to command

The `moreutils` package includes errno, ifdata, ifne, isutf8, lckdo, mispipe, pee and sponge.
The remaining programs are included in the `moreutils-parallel`, `moreutils-perl`, `chronic` and `ts` packages.

%package parallel
Summary:        Run multiple jobs at once
License:        GPL-2.0-only
Conflicts:      gnu_parallel

%description parallel
parallel [options] [command]-- [argument ...]

parallel runs the specified command, passing it a single one of the specified arguments.
This is repeated for each argument. Jobs may be run in parallel. The default is to run one job per CPU.

%package perl
# Utils with only a perl-base requirment should end up here
Summary:        Additional Unix Utilities — Perl scripts
License:        GPL-2.0-or-later
Requires:       perl(File::Basename)
Requires:       perl(File::Path)
Requires:       perl(File::Spec)
Requires:       perl(File::Temp)
Requires:       perl(Getopt::Long)
Requires:       perl(IO::Handle)
Requires:       perl(strict)
Requires:       perl(warnings)
Provides:       moreutils:%{_bindir}/combine
Provides:       moreutils:%{_bindir}/vidir
Provides:       moreutils:%{_bindir}/vipe
Provides:       moreutils:%{_bindir}/zrun
BuildArch:      noarch

%description perl
This is a growing collection of the Unix tools that nobody thought to write long ago, when Unix was young.

This subpackage includes the following utilities:

  - combine: combine the lines in two files using boolean operations
  - vidir: edit a directory in your text editor
  - vipe: insert a text editor into a pipe
  - zrun: automatically uncompress arguments to command

%package -n chronic
#requires perl-IPC-Run
Summary:        Runs a command quietly unless it fails
License:        GPL-2.0-or-later
Requires:       perl(Getopt::Std)
Requires:       perl(IPC::Run)
Requires:       perl(strict)
Requires:       perl(warnings)
Provides:       moreutils:%{_bindir}/chronic
BuildArch:      noarch

%description -n chronic
chronic runs a command, and arranges for its standard out and standard
error to only be displayed if the command fails (exits nonzero or crashes).
If the command succeeds, any extraneous output will be hidden.

A common use for chronic is for running a cron job. Rather than
trying to keep the command quiet, and having to deal with mails containing
accidental output when it succeeds, and not verbose enough output when it
fails, you can just run it verbosely always, and use chronic to hide
the successful output.

%package -n ts
#requires perl, perl-TimeDate and perl-Time-Duration
Summary:        Timestamp standard input
License:        GPL-2.0-or-later
Requires:       perl(Getopt::Long)
Requires:       perl(POSIX)
Requires:       perl(strict)
Requires:       perl(warnings)
Requires:       perl(Date::Parse)
Requires:       perl(Time::Duration)
Requires:       perl(Time::HiRes)
Provides:       moreutils:%{_bindir}/ts
BuildArch:      noarch

%description -n ts
ts adds a timestamp to the beginning of each line of input.

It supports custom time formats as in the strftime function. It also supports converting existing timestamps in input to relative ones.

%prep
%autosetup -p1


%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
export LDFLAGS="%{?build_ldflags}"

%if 0%{?suse_version}
export DOCBOOKXSL="%{_datadir}/xml/docbook/stylesheet/nwalsh/current"
%endif
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version}
export DOCBOOKXSL="%{_datadir}/sgml/docbook/xsl-stylesheets"
%endif
%make_build
echo "### before install ###"

%install
%make_install
echo "### after install ###"

%check
cd is_utf8
./test.sh

%files
%license COPYING debian/copyright
%doc README is_utf8/README.md
%{_mandir}/man1/errno.1*
%{_mandir}/man1/ifdata.1*
%{_mandir}/man1/ifne.1*
%{_mandir}/man1/isutf8.1*
%{_mandir}/man1/lckdo.1*
%{_mandir}/man1/mispipe.1*
%{_mandir}/man1/pee.1*
%{_mandir}/man1/sponge.1*
%{_bindir}/errno
%{_bindir}/ifdata
%{_bindir}/ifne
%{_bindir}/isutf8
%{_bindir}/lckdo
%{_bindir}/mispipe
%{_bindir}/pee
%{_bindir}/sponge

%files parallel
%doc README
%license COPYING debian/copyright
%{_mandir}/man1/parallel.1.gz
%{_bindir}/parallel

%files perl
%doc README
%license COPYING
%{_mandir}/man1/combine.1*
%{_mandir}/man1/vidir.1*
%{_mandir}/man1/vipe.1*
%{_mandir}/man1/zrun.1*
%{_bindir}/combine
%{_bindir}/vidir
%{_bindir}/vipe
%{_bindir}/zrun

%files -n chronic
%doc README
%license COPYING
%{_mandir}/man1/chronic.1.gz
%{_bindir}/chronic

%files -n ts
%doc README
%license COPYING
%{_mandir}/man1/ts.1.gz
%{_bindir}/ts

%changelog
* Mon Dec  9 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 0.70
  * vidir: Improve zero padding to support larger directories, and also avoid unncessary padding.
  * zrun: Add support for zstd compression
  * ts: Do not accept extra args and always read from stdin (deb#1041291)
* Wed Nov 29 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 0.68
  * popen: Use pclose, fixing compile warning.
  * vidir: Zero pad line numbers to work better when used with a small tab size such as 2.
* Fri Aug 26 2022 Bruno Pitrus <brunopitrus@hotmail.com>
- Do not strip debuginfo
  * makefile.patch
- Do not make parallel require the main package, the utilities are standalone.
- Split the programs with additional requirements (Perl) to a separate subpackage.
* Sun May 29 2022 Dirk Müller <dmueller@suse.com>
- update to 0.67:
  * README: Formalize that I am not adding new tools to moreutils,
    and have not for a long while. This package needs someone new to
    take over editorial responsibility.
  * Makefile: Install man pages without executable bit.
    Thanks, meator
  * ifne.1: Improve example that pipes to mail to avoid escape
    sequences.
* Wed Sep 29 2021 Paolo Stivanin <info@paolostivanin.com>
- update to 0.66:
  * vipe: When no output is piped into vipe, and stdin is connected to
    the terminal, don't read from stdin before opening the editor.
    This allows eg: vipe | command
  * chronic: With -v, flush stdout after printing "STDERR" header.
* Mon Feb  8 2021 Dirk Müller <dmueller@suse.com>
- update to 0.65:
  * vipe: Added --suffix option.
  * ifdata: fail when -ph is given but no hwaddr is available
* Sat Oct 10 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.64:
  * parallel: fix typo in usage message.
  * Makefile: Propagate compiler and linker flags when building is_utf8.
  * ts: Fix parsing of ISO-8601 dates.
  * parallel: Allow compiling with uClibc-ng, which does not have getloadavg.
* Fri Apr 19 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.63
  * vipe: Clean up temp file even when it exits with an error.
    Thanks, Stig Palmquist.
  * ts: Fix ts -m %%.s to not output negative microseconds.
    Thanks, Dima Kogan
  * sponge: Fix bug in -a mode that doubled original content of
    file when the temp file is located on a different filesystem.
* Tue Apr 24 2018 aloisio@gmx.com
- Added missing runtime requirement for chronic
* Wed Feb 28 2018 aloisio@gmx.com
- Update to version 0.62
  * ts: Add -m option to use monotonic clock.
    Thanks, Ben Leinweber
  * ts: Added %%.T format like %%T but with hi-res.
    Thanks, Matt Koscica
  * pee: Ignore SIGPIPE and write errors caused by the command
    not consuming all its input. Closes: #697052
    Thanks, Ole Jørgen Brønner
  * chronic: document return value semantics of -e option.
    Closes: #867167
    Thanks, Daniel Shahaf
  * vidir: reword man page to more explicit mention 'file' args.
    Closes: #885221
    Thanks, Daniel Shahaf
  * pee: Don't buffer input, bringing behavior into line with tee.
    Thanks, Sauerbeck Tilman
* Mon May 22 2017 aloisio@gmx.com
- Update to version 0.61
  * chronic: Flush output more often to better preserve stdout,err
    ordering. Thanks, Miroslav Šustek
* Mon Sep 12 2016 aloisio@gmx.com
- Update to version 0.60
  * New implementation of isutf8 by Julien Palard.
    + Noncharacters (ending with 0xFFFF and 0xFFFE)
    were considered invalid when encoded in utf8,
    according to the unicode standard they are valid:
    "However, they are not illegal in interchange, nor
    does their presence cause Unicode text to be
    ill-formed."
    + \xf4\xbf\xbf\xbf was considered valid UTF8, which
    is not: after 0xF4 the following byte should be
    between 80 and 8F.
    + This implementation does not try to decode the stream,
    so it checks it faster.
    + Add --list option. Closes: #691330
  * Support bullding in Cygwin. Thanks, StalkR
  * OSX build fix. Thanks, Tony Kelman.
- Fixed RPM_OPT_FLAGS
* Fri Apr 22 2016 aloisio@gmx.com
- Update to version 0.59
  * Makefile: add DOCBOOKXSL setting.
    Thanks, Kevin Bullock
  * parallel: include signal.h to fix warning when building with clang
    Thanks, Kevin Bullock
  * chronic: Added -v option for more verbose output.
    Thanks, Tomas Mudrunka
  * chronic: Added -e option to display any stderr.
    Thanks, Tomas Mudrunka
  version 0.58:
  * OpenBSD compile fix.
    Thanks, Michael Reed.
  * ts: Quiet perl's complaints about utf-8. Closes: #812143
    Thanks, Nicolas Schier.
- Removed Makefile.patch and Makefile-RHEL.patch and replaced
  them with variable setting
* Tue Jul 28 2015 aloisio@gmx.com
- Update to version 0.57
  * Avoid using non-portable error() in ifdata, a portability
    reversion introduced in 0.56.
  version 0.56:
  * ifdata: Fix error messages when a non-existent network
    interface is queried. Closes: #386754 Thanks, Nicolas Schier
  * errno.docbook: Fix typo. Closes: #749399
  * vidir: Create missing target directories. Closes: #728688
    Thanks, Nicolas Schier
* Sun Feb  8 2015 aloisio@gmx.com
- Update to version 0.55
  * parallel: serialise output through internal pipe.
    Closes: #704125 Thanks, Nicolas Schier.
  * sponge: add append option '-a'.
    Closes: #623197 Thanks, Nicolas Schier.
* Sun Dec 14 2014 aloisio@gmx.com
- Split parallel to a separate package
- Fixed build problem on RHEL
* Fri Dec 12 2014 aloisio@gmx.com
- Update to version 0.54
* Fri Jun  7 2013 Werner Flamme <w.flamme@web.de>
- version 0.48 added to my repo, since no one else provides it
* Sat May  4 2013 Joey Hess <joeyh@debian.org>
- moreutils (0.48) unstable; urgency=low
  * Allow overriding PREFIX and CFLAGS to make the build more flexible
    (Thanks, Ben Walton)
  * Typo. Closes: #697113
  * ts: -i enables incremental timestamping.
    Thanks, Thomas Vander Stichele
  * ts: Support single-digit day dates.
    Thanks, Peter Lunicks
  * sponge: Check fclose to detect certian short reads. Closes: #704453
